genderapi_validate_phone: Validate a phone number

View source: R/account.R

genderapi_validate_phoneR Documentation

Validate a phone number

Description

Sends one POST /phone/validate request. It costs 1 credit, including for invalid numbers, and is never retried.

Usage

genderapi_validate_phone(number, country = NULL, client = genderapi_client())

Arguments

number

Phone number, 3 to 32 characters of digits, spaces, parentheses and hyphens with an optional leading +.

country

Optional upper-case ISO 3166-1 alpha-2 code used for numbers without an international prefix.

client

A genderapi_client().

Value

A genderapi_phone list. data has valid, possible, e164, country and country_calling_code.

Examples

## Not run: 
genderapi_validate_phone("+90 212 555 01 01")$data$valid

## End(Not run)

genderapi documentation built on Oct. 1, 2026, 5:13 p.m.